Crate ghlink

source ·

Structs

Enums

Functions

  • Returns the GitHub blob URL for the file at path with the given link_opts.
  • Returns the repository URL.
  • Search for text in the file at path and return the line numbers.